summaryrefslogtreecommitdiffstats
path: root/remoting/client/frame_consumer.h
diff options
context:
space:
mode:
authorwez@chromium.org <wez@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-01-24 02:53:50 +0000
committerwez@chromium.org <wez@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-01-24 02:53:50 +0000
commitbfe3010dd8c3dfc7a62d791bacdc51569ca94055 (patch)
treeb6afadaac6596e4f3435f221a9dfd525c2d43600 /remoting/client/frame_consumer.h
parent0f514a875652950650f1c51164a62660fac28dc6 (diff)
downloadchromium_src-bfe3010dd8c3dfc7a62d791bacdc51569ca94055.zip
chromium_src-bfe3010dd8c3dfc7a62d791bacdc51569ca94055.tar.gz
chromium_src-bfe3010dd8c3dfc7a62d791bacdc51569ca94055.tar.bz2
Replace RectVectors with SkRegions in Decoder.
BUG=105401 Review URL: http://codereview.chromium.org/9277001 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@118790 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'remoting/client/frame_consumer.h')
-rw-r--r--remoting/client/frame_consumer.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/remoting/client/frame_consumer.h b/remoting/client/frame_consumer.h
index 65b0c64..de56d81 100644
--- a/remoting/client/frame_consumer.h
+++ b/remoting/client/frame_consumer.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2011 The Chromium Authors. All rights reserved.
+// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -40,13 +40,13 @@ class FrameConsumer {
virtual void ReleaseFrame(media::VideoFrame* frame) = 0;
// OnPartialFrameOutput() is called every time at least one rectangle of
// output is produced. The |frame| is guaranteed to have valid data for every
// region included in the |rects| list.
//
// Both |frame| and |rects| are guaranteed to be valid until the |done|
// callback is invoked.
virtual void OnPartialFrameOutput(media::VideoFrame* frame,
- RectVector* rects,
+ SkRegion* region,
const base::Closure& done) = 0;
private:
@@ -40,13 +40,13 @@ class FrameConsumer {
virtual void ReleaseFrame(media::VideoFrame* frame) = 0;
// OnPartialFrameOutput() is called every time at least one rectangle of
- // output is produced. The |frame| is guaranteed to have valid data for every
- // region included in the |rects| list.
+ // output is produced. The |frame| is guaranteed to have valid data for all
+ // of |region|.
//
@@ -40,13 +40,13 @@ class FrameConsumer {
//
- // Both |frame| and |rects| are guaranteed to be valid until the |done|
+ // Both |frame| and |region| are guaranteed to be valid until the |done|
// callback is invoked.
virtual void OnPartialFrameOutput(media::VideoFrame* frame,